==> spip_3.2.11.orig.tar.xz: plugins-dist/dump/lang/dump_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Basea berreskuratu ',

	// I
	'info_restauration_sauvegarde' => '@archive@ babeskopiaren leheneratzea',
	'info_sauvegarde' => 'Babeskopia',
	'info_sauvegarde_reussi_02' => 'Basea ecrire/data/@archive@-ean gorde da. Ahal zara',
	'info_sauvegarde_reussi_03' => 'kudeaketara itzuli',
	'info_sauvegarde_reussi_04' => 'zure gunearen.',

	// T
	'texte_admin_tech_01' => 'Aukera honek basearen edukia ecrire/data direktorioan bilduko den fitxategi batean gordetzen uzten dizu.Halaber ez ahaztu IMG/direktorioaren osotasuna berreskuratzea, artikuluetan eta ataletan erabilitako irudiak eta dokumentuak dituena.',
	'texte_admin_tech_02' => 'kontuz: babeskopia hau SPIP-en bertsio berdinarekin instalatutako gune batean bakarrik leheneratzen ahalko da. Horregatik ez da batez ere « basea hustu » behar, babeskopia berrinstalatzeko zain egonez eguneratze baten ondoren... <a href="@spipnet@">SPIPen dokumentazioa</a> kontsultatu.', # MODIF
	'texte_restaurer_base' => 'Ziurtasunkopiaren edukia berreskuratu',
	'texte_restaurer_sauvegarde' => 'Aukera honekin lehenago egindako ziurtasun kopia bat berrezarri ahal duzu. Hau egin ahal izateko,ziurtasun kopia daukan fitxeroa ecrire/data/ direktorioan egon behar da. Kontuz ibilifuntzionalitate honekin: aldaketak edo galtze tenporalak atzeraezinak dira.', # MODIF
	'texte_sauvegarde' => 'Basean ziurtasun kopia bat sortu.',
	'texte_sauvegarde_base' => 'Basean ziurtasun kopia bat sortu.'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=eu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Basea berreskuratu ',

	// I
	'info_restauration_sauvegarde' => '@archive@ babeskopiaren leheneratzea',
	'info_sauvegarde' => 'Babeskopia',
	'info_sauvegarde_reussi_02' => 'Basea ecrire/data/@archive@-ean gorde da. Ahal zara',
	'info_sauvegarde_reussi_03' => 'kudeaketara itzuli',
	'info_sauvegarde_reussi_04' => 'zure gunearen.',

	// T
	'texte_admin_tech_01' => 'Aukera honek basearen edukia ecrire/data direktorioan bilduko den fitxategi batean gordetzen uzten dizu.Halaber ez ahaztu IMG/direktorioaren osotasuna berreskuratzea, artikuluetan eta ataletan erabilitako irudiak eta dokumentuak dituena.',
	'texte_admin_tech_02' => 'kontuz: babeskopia hau SPIP-en bertsio berdinarekin instalatutako gune batean bakarrik leheneratzen ahalko da. Horregatik ez da batez ere « basea hustu » behar, babeskopia berrinstalatzeko zain egonez eguneratze baten ondoren... <a href="@spipnet@">SPIPen dokumentazioa</a> kontsultatu.', # MODIF
	'texte_restaurer_base' => 'Ziurtasunkopiaren edukia berreskuratu',
	'texte_restaurer_sauvegarde' => 'Aukera honekin lehenago egindako ziurtasun kopia bat berrezarri ahal duzu. Hau egin ahal izateko,ziurtasun kopia daukan fitxeroa ecrire/data/ direktorioan egon behar da. Kontuz ibilifuntzionalitate honekin: aldaketak edo galtze tenporalak atzeraezinak dira.', # MODIF
	'texte_sauvegarde' => 'Basean ziurtasun kopia bat sortu.',
	'texte_sauvegarde_base' => 'Basean ziurtasun kopia bat sortu.',
];
